@@ -1823,10 +1823,10 @@ ensure_bitrate (GstVaapiEncoderH265 * encoder)
         /* Fixme: Provide better estimation */
         /* Using a 1/6 compression ratio */
         /* 12 bits per pixel fro yuv420 */
+        guint64 factor = encoder->luma_width * encoder->luma_height * 12 / 6;
         base_encoder->bitrate =
-            (encoder->luma_width * encoder->luma_height * 12 / 6) *
-            GST_VAAPI_ENCODER_FPS_N (encoder) /
-            GST_VAAPI_ENCODER_FPS_D (encoder) / 1000;
+            gst_util_uint64_scale (factor, GST_VAAPI_ENCODER_FPS_N (encoder),
+            GST_VAAPI_ENCODER_FPS_D (encoder)) / 1000;
         GST_INFO ("target bitrate computed to %u kbps", base_encoder->bitrate);
       }
       break;
@@ -1905,11 +1905,11 @@ reset_properties (GstVaapiEncoderH265 * encoder)
   if (encoder->num_bframes > (base_encoder->keyframe_period + 1) / 2)
     encoder->num_bframes = (base_encoder->keyframe_period + 1) / 2;
 
-  if (encoder->num_bframes)
-    encoder->cts_offset = GST_SECOND * GST_VAAPI_ENCODER_FPS_D (encoder) /
-        GST_VAAPI_ENCODER_FPS_N (encoder);
+  if (encoder->num_bframes > 0 && GST_VAAPI_ENCODER_FPS_N (encoder) > 0)
+    encoder->cts_offset = gst_util_uint64_scale (GST_SECOND,
+        GST_VAAPI_ENCODER_FPS_D (encoder), GST_VAAPI_ENCODER_FPS_N (encoder));
   else
-    encoder->cts_offset = 0;
+    encoder->cts_offset = GST_CLOCK_TIME_NONE;
 
   /* init max_poc */
   encoder->log2_max_pic_order_cnt =
